@@ -1,17 +1,17 @@
 package version
 
 var (
-	Version = "7.9.2"
+	Version = "7.9.4"
 	// PriorVersion - prior version
-	PriorVersion = "7.9.1"
+	PriorVersion = "7.9.3"
 )
 
 const (
 	// LatestVersion product version supported
-	LatestVersion        = "7.9.2"
-	CompactLatestVersion = "792"
+	LatestVersion        = "7.9.4"
+	CompactLatestVersion = "794"
 	// LastMicroVersion product version supported
-	LastMicroVersion = "7.9.1"
+	LastMicroVersion = "7.9.3"
 	// LastMinorVersion product version supported
 	LastMinorVersion = "7.7.0"
 )
@@ -29,6 +29,8 @@ var OperandVersionFromOperatorVersion map[string]string = map[string]string{
 	"7.9.0":  "7.9.0",
 	"7.9.1":  "7.9.1",
 	"7.9.2":  "7.9.2",
+	"7.9.3":  "7.9.3",
+	"7.9.4":  "7.9.4",
 }
 var FullVersionFromMinorVersion map[string]string = map[string]string{
 	"70": "7.7.0",
@@ -39,6 +41,8 @@ var FullVersionFromMinorVersion map[string]string = map[string]string{
 	"90": "7.9.0",
 	"91": "7.9.1",
 	"92": "7.9.2",
+	"93": "7.9.3",
+	"94": "7.9.4",
 }
 
 var CompactFullVersionFromMinorVersion map[string]string = map[string]string{
@@ -50,6 +54,8 @@ var CompactFullVersionFromMinorVersion map[string]string = map[string]string{
 	"90": "790",
 	"91": "791",
 	"92": "792",
+	"93": "793",
+	"94": "794",
 }
 
 var CompactVersionFromVersion map[string]string = map[string]string{
@@ -61,6 +67,8 @@ var CompactVersionFromVersion map[string]string = map[string]string{
 	"7.9.0": "790",
 	"7.9.1": "791",
 	"7.9.2": "792",
+	"7.9.3": "793",
+	"7.9.4": "794",
 }
 
 var FullVersionFromCompactVersion map[string]string = map[string]string{
@@ -72,6 +80,8 @@ var FullVersionFromCompactVersion map[string]string = map[string]string{
 	"790": "7.9.0",
 	"791": "7.9.1",
 	"792": "7.9.2",
+	"793": "7.9.3",
+	"794": "7.9.4",
 }
 
 var MinorVersionFromFullVersion map[string]string = map[string]string{
@@ -83,6 +93,8 @@ var MinorVersionFromFullVersion map[string]string = map[string]string{
 	"7.9.0": "90",
 	"7.9.1": "91",
 	"7.9.2": "92",
+	"7.9.3": "93",
+	"7.9.4": "94",
 }
 
 //The yacfg profile to use for a given full version of broker
@@ -95,6 +107,8 @@ var YacfgProfileVersionFromFullVersion map[string]string = map[string]string{
 	"7.9.0": "7.9.0",
 	"7.9.1": "7.9.0",
 	"7.9.2": "7.9.0",
+	"7.9.3": "7.9.0",
+	"7.9.4": "7.9.0",
 }
 
 var YacfgProfileName string = "amq_broker"
